@@ -29,28 +29,65 @@ pub type CustomCommand = extern "C" fn(Context) -> HandlerResult;
 #[cfg_attr(target_arch = "x86", link(name = "cleo_redux"))]
 #[cfg_attr(target_arch = "x86_64", link(name = "cleo_redux64"))]
 extern "C" {
+    /// since v1
+    ///
     /// Returns the current SDK version as an integer number.
     fn GetSDKVersion() -> i32;
+    /// since v1
+    ///
     /// Returns the current host (game) id
     fn GetHostId() -> HostId;
+    /// since v1
+    ///
+    /// Resolves a path to the absolute path
+    ///     - absolute path gets resolved as is
+    /// - path starting with "CLEO/" gets resolved relative to the CLEO directory
+    ///    * either {game}\CLEO or
+    ///    * {user}\AppData\Roaming\CLEO Redux\CLEO
+    ///  - all other paths get resolved relative to the cwd (game directory)
+    fn ResolvePath(src: *const c_char, dest: *mut c_char);
+    /// since v1
+    ///
     /// Returns the absolute path to the CLEO directory
-    fn GetCLEOFolder(buf: *mut c_char);
+    fn GetCLEOFolder(dest: *mut c_char);
+    /// since v1
+    ///
+    /// Returns the absolute path to the current working directory (normally the game directory)
+    fn GetCwd(dest: *mut c_char);
+    /// since v1
+    ///
     /// Prints a new entry to the cleo_redux.log
     fn Log(text: *const c_char);
+    /// since v1
+    ///
     /// Registers a new callback handler for the command with the given name. Permission token is required for unsafe operations interacting with the user environment (e.g. mem, fs, net)
     fn RegisterCommand(name: *const c_char, cb: CustomCommand, permission: *const c_char);
+    /// since v1
+    ///
     /// Reads an integer argument (32 or 64 bit depending on target platform)
     fn GetIntParam(ctx: Context) -> isize;
+    /// since v1
+    ///
     /// Reads a floating-point argument
     fn GetFloatParam(ctx: Context) -> f32;
+    /// since v1
+    ///
     /// Reads a string argument
-    fn GetStringParam(ctx: Context, buf: *mut c_char, len: u8);
+    fn GetStringParam(ctx: Context, dest: *mut c_char, maxlen: u8);
+    /// since v1
+    ///
     /// Writes the integer value (32 or 64 bit depending on target platform)
     fn SetIntParam(ctx: Context, value: isize);
+    /// since v1
+    ///
     /// Writes the floating-point value
     fn SetFloatParam(ctx: Context, value: f32);
+    /// since v1
+    ///
     /// Writes the string value
-    fn SetStringParam(ctx: Context, buf: *const c_char, len: u8);
+    fn SetStringParam(ctx: Context, src: *const c_char);
+    /// since v1
+    ///
     /// Sets the status of the current condition
     fn UpdateCompareFlag(ctx: Context, result: bool);
 }
@@ -61,6 +98,8 @@ macro_rules! sz {
     };
 }
 
+/// since v1
+///
 /// Registers a new callback handler for the command with the given name. Permission token is required for unsafe operations interacting with the user environment (e.g. mem, fs, net)
 #[allow(dead_code)]
 pub fn register_command(name: &str, cb: CustomCommand, permission: Option<&str>) {
@@ -72,21 +111,29 @@ pub fn register_command(name: &str, cb: CustomCommand, permission: Option<&str>)
     }
 }
 
+/// since v1
+///
 /// Prints a new entry to the cleo_redux.log
 pub fn log<T: Into<Vec<u8>>>(text: T) {
     unsafe { Log(sz!(text)) };
 }
 
+/// since v1
+///
 /// Returns the current SDK version as an integer number.
 pub fn get_sdk_version() -> i32 {
     unsafe { GetSDKVersion() }
 }
 
+/// since v1
+///
 /// Returns the current host (game) id
 pub fn get_host_id() -> HostId {
     unsafe { GetHostId() }
 }
 
+/// since v1
+///
 /// Reads a string argument
 pub fn get_string_param(ctx: Context) -> String {
     let mut buf = [0i8; SDK_STRING_MAX_LEN];
@@ -94,39 +141,75 @@ pub fn get_string_param(ctx: Context) -> String {
     to_rust_string(buf.as_ptr())
 }
 
+/// since v1
+///
 /// Writes the string value
 pub fn set_string_param(ctx: Context, value: String) {
-    let len = value.len() as u8;
-    unsafe { SetStringParam(ctx, sz!(value), len) };
+    unsafe { SetStringParam(ctx, sz!(value)) };
 }
 
+/// since v1
+///
 /// Reads an integer argument (32 or 64 bit depending on target platform)
 pub fn get_int_param(ctx: Context) -> isize {
     unsafe { GetIntParam(ctx) }
 }
 
+/// since v1
+///
 /// Writes the integer value (32 or 64 bit depending on target platform)
 pub fn set_int_param(ctx: Context, value: isize) {
     unsafe { SetIntParam(ctx, value) };
 }
 
+/// since v1
+///
 /// Returns the absolute path to the CLEO directory
 pub fn get_cleo_folder() -> std::path::PathBuf {
-    let mut buf = [0i8; 255];
+    let mut buf = [0i8; 256];
     unsafe { GetCLEOFolder(buf.as_mut_ptr()) };
     std::path::Path::new(&to_rust_string(buf.as_ptr())).into()
 }
 
+/// since v1
+///
+/// Returns the absolute path to the current working directory (normally the game directory)
+pub fn get_cwd() -> std::path::PathBuf {
+    let mut buf = [0i8; 256];
+    unsafe { GetCwd(buf.as_mut_ptr()) };
+    std::path::Path::new(&to_rust_string(buf.as_ptr())).into()
+}
+
+/// since v1
+///
+/// Resolves a path to the absolute path
+///     - absolute path gets resolved as is
+/// - path starting with "CLEO/" gets resolved relative to the CLEO directory
+///    * either {game}\CLEO or
+///    * {user}\AppData\Roaming\CLEO Redux\CLEO
+///  - all other paths get resolved relative to the cwd (game directory)
+pub fn resolve_path(path: &str) -> std::path::PathBuf {
+    let mut dest = [0i8; 256];
+    unsafe { ResolvePath(sz!(path), dest.as_mut_ptr()) };
+    std::path::Path::new(&to_rust_string(dest.as_ptr())).into()
+}
+
+/// since v1
+///
 /// Reads a floating-point argument
 pub fn get_float_param(ctx: Context) -> f32 {
     unsafe { GetFloatParam(ctx) }
 }
 
+/// since v1
+///
 /// Writes the floating-point value
 pub fn set_float_param(ctx: Context, value: f32) {
     unsafe { SetFloatParam(ctx, value) };
 }
 
+/// since v1
+///
 /// Sets the status of the current condition
 pub fn update_compare_flag(ctx: Context, value: bool) {
     unsafe { UpdateCompareFlag(ctx, value) }
